@@ -686,6 +686,12 @@ class GitLibMixin:
                 # Return whatever the TLS/SSH library thinks about the cert
                 return True
 
+            def push_update_reference(self, refname, message):
+                if message is not None:
+                    raise Exception(
+                        f"Remote rejected push with message: {message}"
+                    )
+
         checkedOutBranch = self.__checkedOutBranch
         remoteBranchName = f"{remoteName}/{checkedOutBranch.shorthand}"
         remoteBranch = self._repo.branches[remoteBranchName]
@@ -700,18 +706,6 @@ class GitLibMixin:
             callbacks=RemoteCallback(),
         )
 
-        # Check if the push was successful
-        remote = self._repo.remotes[remoteName]
-        remote.fetch(callbacks=RemoteCallback())
-        # Reload the remoteBranch reference
-        remoteBranch = self._repo.branches[remoteBranchName]
-
-        if remoteBranch.target != checkedOutBranch.target:
-            raise Exception(
-                "Remote rejected push. Please check if you have permissions "
-                "to push to the remote or file sizes in Git are not too big"
-            )
-
     def pullFromRemote(
         self, remoteName: str, username: str, password: str = None
     ) -> None:
